@@ -12,6 +12,7 @@ from code_loader.contract.datasetclasses import SectionCallableInterface, InputH
     CustomMultipleReturnCallableInterfaceMultiArgs, DatasetBaseHandler, custom_latent_space_attribute, \
     RawInputsForHeatmap, VisualizerHandlerData, MetricHandlerData, CustomLossHandlerData, SamplePreprocessResponse
 from code_loader.contract.enums import LeapDataType, DataStateEnum, DataStateType, MetricDirection, DatasetMetadataType
+from code_loader.contract.mapping import NodeConnection, NodeMapping, NodeMappingType
 from code_loader.contract.responsedataclasses import DatasetTestResultPayload
 from code_loader.contract.visualizer_classes import map_leap_data_type_to_visualizer_class
 from code_loader.default_losses import loss_name_to_function
@@ -43,6 +44,8 @@ class LeapBinder:
         self._extend_with_default_metrics()
         self._extend_with_default_losses()
 
+        self.mapping_connections: List[NodeConnection] = []
+
         self.batch_size_to_validate: Optional[int] = None
 
     def _extend_with_default_visualizers(self) -> None:
@@ -307,7 +310,7 @@ class LeapBinder:
         metric_handler_data = MetricHandlerData(name, regular_arg_names, direction, compute_insights)
         self.setup_container.metrics.append(MetricHandler(metric_handler_data, function))
 
-    def add_prediction(self, name: str, labels: List[str], channel_dim: int = -1) -> None:
+    def add_prediction(self, name: str, labels: List[str], channel_dim: int = -1, prediction_index: Optional[int]=None) -> None:
         """
         Add prediction labels to the setup.
 
@@ -322,6 +325,11 @@ class LeapBinder:
             leap_binder.add_prediction(name='class_labels', labels=['cat', 'dog'])
         """
         self.setup_container.prediction_types.append(PredictionTypeHandler(name, labels, channel_dim))
+        if prediction_index is not None:
+            node_connection = NodeConnection(NodeMapping(name, NodeMappingType.PredictionLabels),
+                                             {'temp': NodeMapping('', NodeMappingType(f'Prediction{prediction_index}'))})
+
+            self.mapping_connections.append(node_connection)
 
     def set_ground_truth(self, function: SectionCallableInterface, name: str) -> None:
         """
@@ -505,6 +513,10 @@ class LeapBinder:
                 for i, (single_metadata_name, single_metadata_result) in enumerate(raw_result.items()):
                     metadata_test_result = metadata_test_result_payloads[i]
 
+                    if not isinstance(single_metadata_result, (int, str, bool, float, np.unsignedinteger, np.signedinteger, np.bool_, np.floating)):
+                        raise Exception(f"Unsupported return type of metadata {single_metadata_name}."
+                                        f"The return type should be one of [int, float, str, bool]. Got {type(single_metadata_result)}")
+
                     metadata_type = None
                     if single_metadata_result is None:
                         if state != DataStateEnum.training and test_result[i].name == f'{dataset_base_handler.name}_{single_metadata_name}':
